@@ -2,7 +2,7 @@ from jinja2 import Template
 
 from mkdocs_apidoc.collect import obj_from_string
 from mkdocs_apidoc.docstring import doc_from_obj
-from mkdocs_apidoc.inspections import autodoc_module
+from mkdocs_apidoc.inspections import autodoc_module, markdown_table
 
 
 def register_template_function(t: Template, f):
@@ -31,6 +31,11 @@ def auto_module(s: str) -> str:
     return autodoc_module(obj)
 
 
+def dict_to_markdown(s: str) -> str:
+    obj = obj_from_string(s)
+    return markdown_table(obj)
+
+
 def render_page(page: str) -> str:
     """render the page
 
@@ -43,4 +48,5 @@ def render_page(page: str) -> str:
     t = Template(page)
     register_template_function(t, auto_object)
     register_template_function(t, auto_module)
+    register_template_function(t, dict_to_markdown)
     return t.render()
